***************************
* File: a_b_c.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\Second Round\cisco\a_b_c.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "a_b_c", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "a_b_c", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen cisco_code = group(cisco)
order cisco cisco_code

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.

foreach v of varlist       exced_caisse{
	gen error01`v' = (caisse_suffi== 1 & `v'< . )
} 
foreach v of varlist       repar_caisse exced_caisse{
	gen error02`v' = (caisse_suffi== 2 & `v'< . )
} 
foreach v of varlist      insuf_caisse {
	gen error02`v' = (caisse_suffi== 2 & `v'< "" )
} 
foreach v of varlist       repar_caisse {
	gen error03`v' = (caisse_suffi== 3 & `v'< . )
}
foreach v of varlist      insuf_caisse {
	gen error03`v' = (caisse_suffi== 3 & `v'< "" )
} 
**************************************************
***  Identify other internal coherence issues
**************************************************

**************************************************
***  Identify illegal responses
**************************************************

log using "a_b_c label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

log using "a_b_c grubbs", replace
preserve
global discrete (	chgt_nosubv	comment_subv2	comment_subv1	per_ensgt	chgt_ensgt	exced_subv	repar_subv	comment_cais2	comment_cais1	exced_caisse	repar_caisse	subv_suffi	caisse_suffi	trs_tresor	trs_cirfin	trs_dren	poste7	poste6		poste4	poste3	poste2	poste1	fonct7	fonct6	fonct4	fonct3	fonct2	fonct1 )
global name (     cisco dren nom_rep1 nom_rep2 nom_rep3 nom_rep4 rsn_ret_cais insuf_caisse rsn_ret_dist rsn_long nom_rep6 nom_rep7 insuf_subv)
drop $discrete $name 
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore 

**************************************************
***  Identify errors to be reviewed
**************************************************
drop err* 


**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\cisco"
log using "a_b_c codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\cisco"
save "a_b_c_cleaned_data.dta", replace
