***************************
* File: d_e_f.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\Second Round\cisco\d_e_f.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Madagascar 2006 P E\4- Data\extra\Second Round\cisco"
log using "d_e_f", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "d_e_f", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen cisco_code = group(cisco)
order cisco cisco_code

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.

foreach v of varlist       exced_kit {
	gen error01`v' = (kit_suffi== 1 & `v'< . )
} 
foreach v of varlist       repar_kit exced_kit {
	gen error02`v' = (kit_suffi== 2 & `v'< . )
} 
foreach v of varlist      insuf_kit{
	gen error02`v' = (kit_suffi== 2 & `v'< "" )
} 
foreach v of varlist      repar_kit {
	gen error03`v' = (kit_suffi== 3 & `v'< . )
}
foreach v of varlist      insuf_kit {
	gen error03`v' = (kit_suffi== 3 & `v'< "" )
}

**************************************************
***  Identify illegal responses
**************************************************

log using "d_e_f label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

log using "d_e_f grubbs", replace
preserve
global discrete (		comment_mat	comment_man	exced_man	repar_man	man_suffi	comment_kit	exced_kit	repar_kit	kit_suffi	poste13	poste12	poste11	poste10	poste9	poste8	fonct13	fonct12	fonct11	fonct10	fonct9	fonct8)
global name ( cisco dren insuf_* nom_rep*)
drop $discrete $name 
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore 

**************************************************
***  Identify errors to be reviewed
**************************************************
drop err* 

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\cisco"
log using "d_e_f codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\cisco"
save "d_e_f_cleaned_data.dta", replace
