***************************
* File: G1_caisse_ecole.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\Second Round\cisco\G1_caisse_ecole.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "G1_caisse_ecole", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "G1_caisse_ecole", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen cisco_code = group(cisco)
egen ID=concat( cisco_code num_ecole)
destring ID, replace
order cisco cisco_code ID
label var ID "identifiant unique"

**************************************************
***  Identify illegal responses
**************************************************

log using "G1_caisse_ecole label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

log using "G1_caisse_ecole grubbs", replace
grubbs  montant jour_rec mois_rec an_rec ensgt_fram ensgt_subv mnt_ensgt , level(99.99)
sum grubbs*
log close
drop grubbs*  

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\cisco"
log using "G1_caisse_ecole codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\cisco"
save "G1_caisse_ecole_cleaned_data.dta", replace
